
1.3.0 (2019-05-12)
###################

* pin biocommons dependencies to versions that support 2.7 and 3.5+ [`25bc21f <https://github.com/biocommons/hgvs/commit/25bc21f>`_]

Changes since 1.2.5.post1 (2019-02-01).

Bug Fixes
$$$$$$$$$$

* Fixes `#474 <https://github.com/biocommons/hgvs/issues/474/>`_, fixes `#492 <https://github.com/biocommons/hgvs/issues/492/>`_: correct for stop gain located at termination codon (`#518 <https://github.com/biocommons/hgvs/issues/518/>`_)
* Fixes `#501 <https://github.com/biocommons/hgvs/issues/501/>`_: Add c_to_p support for inversion (`#502 <https://github.com/biocommons/hgvs/issues/502/>`_)

New Features
$$$$$$$$$$$$$

* Closes `#243 <https://github.com/biocommons/hgvs/issues/243/>`_: implement hgvs-to-vcf translation
* Closes `#499 <https://github.com/biocommons/hgvs/issues/499/>`_: recognize whole-gene dup (c.-i_*j) and assume does not affect protein sequence [`dc48d5d <https://github.com/biocommons/hgvs/commit/dc48d5d>`_]
* Closes `#511 <https://github.com/biocommons/hgvs/issues/511/>`_: Update misc/experimental/vcf-add-hgvs to support newer bioutils and pyvcf [`88e01d4 <https://github.com/biocommons/hgvs/commit/88e01d4>`_]
* Closes `#257 <https://github.com/biocommons/hgvs/issues/257/>`_: Support parsing gene names and optional addition during projection
* Closes `#557 <https://github.com/biocommons/hgvs/issues/557/>`_: Add option to format translation initiation codon variants as `p.Met1?`
p.Met1? is the new default [2cd86b9]
* Added `parse` shorthand for `parse_hgvs_variant` [`69c2aeb <https://github.com/biocommons/hgvs/commit/69c2aeb>`_]
* Added t_to_p in AssemblyMapper [`8f9b69b <https://github.com/biocommons/hgvs/commit/8f9b69b>`_]
* hgvs.easy: Provide single-file import with usable defaults and functional forms for common commands (`#516 <https://github.com/biocommons/hgvs/issues/516/>`_)
* Updated hgvs-guess-plausible-transcripts [`4e2a9d0 <https://github.com/biocommons/hgvs/commit/4e2a9d0>`_]
* Updated default uta to uta_20180821 [`e8206d1 <https://github.com/biocommons/hgvs/commit/e8206d1>`_]


Internal, Developer, and Experimental Changes
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

* Closes `#544 <https://github.com/biocommons/hgvs/issues/544/>`_: Update installation docs [`ae3064c <https://github.com/biocommons/hgvs/commit/ae3064c>`_]
* Closes `#500 <https://github.com/biocommons/hgvs/issues/500/>`_: unpinned setuptools_scm [`bae7e4a <https://github.com/biocommons/hgvs/commit/bae7e4a>`_]
* Closes `#494 <https://github.com/biocommons/hgvs/issues/494/>`_: Removed useless warning (Closing connection; future mapping and validation will fail) [`dfa0c52 <https://github.com/biocommons/hgvs/commit/dfa0c52>`_]
* Added Python syntax highlighting (`#550 <https://github.com/biocommons/hgvs/issues/550/>`_)
* Added doctests for hgvs/utils/norm.py (`#548 <https://github.com/biocommons/hgvs/issues/548/>`_)
* Expose seqrepo reference in SeqFetcher instance [`3ab49e9 <https://github.com/biocommons/hgvs/commit/3ab49e9>`_]
* Fix typo in docs (`#554 <https://github.com/biocommons/hgvs/issues/554/>`_) [`5b25b4f <https://github.com/biocommons/hgvs/commit/5b25b4f>`_]
* When re-raising exception from sequencing fetching, including fetcher implementation and underlying exception message [`42859e4 <https://github.com/biocommons/hgvs/commit/42859e4>`_]
* add 3.7 support to Makefile [`3a89a82 <https://github.com/biocommons/hgvs/commit/3a89a82>`_]
* added link to hgvs notebooks on mybinder.org [`3077d3c <https://github.com/biocommons/hgvs/commit/3077d3c>`_]
* added notebook of hdp output examples [`4fb9617 <https://github.com/biocommons/hgvs/commit/4fb9617>`_]
* don't warn about pickle.load() [`f052d03 <https://github.com/biocommons/hgvs/commit/f052d03>`_]
* emit CRITICAL log message on Python < 3.6 [`b7f320a <https://github.com/biocommons/hgvs/commit/b7f320a>`_]
* expose seqrepo reference in SeqFetcher instance [`3ab49e9 <https://github.com/biocommons/hgvs/commit/3ab49e9>`_]
* fix regexp that didn't use a raw (r"") string (DeepSource) [`f6126f6 <https://github.com/biocommons/hgvs/commit/f6126f6>`_]
* fix: expected results in quick_start.rst doctest were unsorted [`63d5e74 <https://github.com/biocommons/hgvs/commit/63d5e74>`_]
* fixed incompatibilities with newer version of pytest [`ee9426f <https://github.com/biocommons/hgvs/commit/ee9426f>`_]
* fixed redundant exception imports (DeepSource) [`dc6277d <https://github.com/biocommons/hgvs/commit/dc6277d>`_]
* minor code cleanup based on pylint testing [`927864d <https://github.com/biocommons/hgvs/commit/927864d>`_]
* ooops... used f string in 2.7 version :-( [`5c3492a <https://github.com/biocommons/hgvs/commit/5c3492a>`_]
* remove del sequence from variants being tested (and remove re module DeprecationWarnings); and fix latent bugs in tests [`2cb053d <https://github.com/biocommons/hgvs/commit/2cb053d>`_]
* remove relative path in pkg_resources.resource_filename() to eliminate warning about future failure [`19a16d5 <https://github.com/biocommons/hgvs/commit/19a16d5>`_]
* updated pytest mark configuration [`d922495 <https://github.com/biocommons/hgvs/commit/d922495>`_]
